pub unsafe extern "C" fn cef_server_create(
address: *const cef_string_t,
port: u16,
backlog: c_int,
handler: *mut _cef_server_handler_t,
)Expand description
Create a new server that binds to |address| and |port|. |address| must be a valid IPv4 or IPv6 address (e.g. 127.0.0.1 or ::1) and |port| must be a port number outside of the reserved range (e.g. between 1025 and 65535 on most platforms). |backlog| is the maximum number of pending connections. A new thread will be created for each CreateServer call (the “dedicated server thread”). It is therefore recommended to use a different cef_server_handler_t instance for each CreateServer call to avoid thread safety issues in the cef_server_handler_t implementation. The cef_server_handler_t::OnServerCreated function will be called on the dedicated server thread to report success or failure. See cef_server_handler_t::OnServerCreated documentation for a description of server lifespan.