cef_uridecode

Function cef_uridecode 

pub unsafe extern "C" fn cef_uridecode(
    text: *const cef_string_t,
    convert_to_utf8: c_int,
    unescape_rule: cef_uri_unescape_rule_t,
) -> cef_string_userfree_t
Unescapes |text| and returns the result. Unescaping consists of looking for the exact pattern “%XX” where each X is a hex digit and converting to the character with the numerical value of those digits (e.g. “i%20=%203%3b” unescapes to “i = 3;”). If |convert_to_utf8| is true (1) this function will attempt to interpret the initial decoded result as UTF-8. If the result is convertable into UTF-8 it will be returned as converted. Otherwise the initial decoded result will be returned. The |unescape_rule| parameter supports further customization the decoding process.