#[repr(C)]pub struct _cef_shared_process_message_builder_t {
pub base: cef_base_ref_counted_t,
pub is_valid: Option<unsafe extern "C" fn(self_: *mut _cef_shared_process_message_builder_t) -> c_int>,
pub size: Option<unsafe extern "C" fn(self_: *mut _cef_shared_process_message_builder_t) -> usize>,
pub memory: Option<unsafe extern "C" fn(self_: *mut _cef_shared_process_message_builder_t) -> *mut c_void>,
pub build: Option<unsafe extern "C" fn(self_: *mut _cef_shared_process_message_builder_t) -> *mut _cef_process_message_t>,
}Expand description
Structure that builds a cef_process_message_t containing a shared memory region. This structure is not thread-safe but may be used exclusively on a different thread from the one which constructed it.
NOTE: This struct is allocated DLL-side.
Fields
base: cef_base_ref_counted_tBase structure.
is_valid: Option<unsafe extern "C" fn(self_: *mut _cef_shared_process_message_builder_t) -> c_int>Returns true (1) if the builder is valid.
size: Option<unsafe extern "C" fn(self_: *mut _cef_shared_process_message_builder_t) -> usize>Returns the size of the shared memory region in bytes. Returns 0 for invalid instances.
memory: Option<unsafe extern "C" fn(self_: *mut _cef_shared_process_message_builder_t) -> *mut c_void>Returns the pointer to the writable memory. Returns nullptr for invalid instances. The returned pointer is only valid for the life span of this object.
build: Option<unsafe extern "C" fn(self_: *mut _cef_shared_process_message_builder_t) -> *mut _cef_process_message_t>Creates a new cef_process_message_t from the data provided to the builder. Returns nullptr for invalid instances. Invalidates the builder instance.