_cef_task_manager_t

Struct _cef_task_manager_t 

#[repr(C)]
pub struct _cef_task_manager_t { pub base: cef_base_ref_counted_t, pub get_tasks_count: Option<unsafe extern "C" fn(self_: *mut _cef_task_manager_t) -> usize>, pub get_task_ids_list: Option<unsafe extern "C" fn(self_: *mut _cef_task_manager_t, task_idsCount: *mut usize, task_ids: *mut i64) -> c_int>, pub get_task_info: Option<unsafe extern "C" fn(self_: *mut _cef_task_manager_t, task_id: i64, info: *mut _cef_task_info_t) -> c_int>, pub kill_task: Option<unsafe extern "C" fn(self_: *mut _cef_task_manager_t, task_id: i64) -> c_int>, pub get_task_id_for_browser_id: Option<unsafe extern "C" fn(self_: *mut _cef_task_manager_t, browser_id: c_int) -> i64>, }
Structure that facilitates managing the browser-related tasks. The functions of this structure may only be called on the UI thread.

NOTE: This struct is allocated DLL-side.

Fields

base: cef_base_ref_counted_t

Base structure.

get_tasks_count: Option<unsafe extern "C" fn(self_: *mut _cef_task_manager_t) -> usize>

Returns the number of tasks currently tracked by the task manager. Returns 0 if the function was called from the incorrect thread.

get_task_ids_list: Option<unsafe extern "C" fn(self_: *mut _cef_task_manager_t, task_idsCount: *mut usize, task_ids: *mut i64) -> c_int>

Gets the list of task IDs currently tracked by the task manager. Tasks that share the same process id will always be consecutive. The list will be sorted in a way that reflects the process tree: the browser process will be first, followed by the gpu process if it exists. Related processes (e.g., a subframe process and its parent) will be kept together if possible. Callers can expect this ordering to be stable when a process is added or removed. The task IDs are unique within the application lifespan. Returns false (0) if the function was called from the incorrect thread.

get_task_info: Option<unsafe extern "C" fn(self_: *mut _cef_task_manager_t, task_id: i64, info: *mut _cef_task_info_t) -> c_int>

Gets information about the task with |task_id|. Returns true (1) if the information about the task was successfully retrieved and false (0) if the |task_id| is invalid or the function was called from the incorrect thread.

kill_task: Option<unsafe extern "C" fn(self_: *mut _cef_task_manager_t, task_id: i64) -> c_int>

Attempts to terminate a task with |task_id|. Returns false (0) if the |task_id| is invalid, the call is made from an incorrect thread, or if the task cannot be terminated.

get_task_id_for_browser_id: Option<unsafe extern "C" fn(self_: *mut _cef_task_manager_t, browser_id: c_int) -> i64>

Returns the task ID associated with the main task for |browser_id| (value from cef_browser_t::GetIdentifier). Returns -1 if |browser_id| is invalid, does not currently have an associated task, or the function was called from the incorrect thread.