_cef_xml_reader_t

Struct _cef_xml_reader_t 

#[repr(C)]
pub struct _cef_xml_reader_t {
Show 30 fields pub base: cef_base_ref_counted_t, pub move_to_next_node: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> c_int>, pub close: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> c_int>, pub has_error: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> c_int>, pub get_error: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> cef_string_userfree_t>, pub get_type: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> cef_xml_node_type_t>, pub get_depth: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> c_int>, pub get_local_name: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> cef_string_userfree_t>, pub get_prefix: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> cef_string_userfree_t>, pub get_qualified_name: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> cef_string_userfree_t>, pub get_namespace_uri: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> cef_string_userfree_t>, pub get_base_uri: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> cef_string_userfree_t>, pub get_xml_lang: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> cef_string_userfree_t>, pub is_empty_element: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> c_int>, pub has_value: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> c_int>, pub get_value: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> cef_string_userfree_t>, pub has_attributes: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> c_int>, pub get_attribute_count: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> usize>, pub get_attribute_byindex: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t, index: c_int) -> cef_string_userfree_t>, pub get_attribute_byqname: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t, qualifiedName: *const cef_string_t) -> cef_string_userfree_t>, pub get_attribute_bylname: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t, localName: *const cef_string_t, namespaceURI: *const cef_string_t) -> cef_string_userfree_t>, pub get_inner_xml: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> cef_string_userfree_t>, pub get_outer_xml: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> cef_string_userfree_t>, pub get_line_number: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> c_int>, pub move_to_attribute_byindex: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t, index: c_int) -> c_int>, pub move_to_attribute_byqname: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t, qualifiedName: *const cef_string_t) -> c_int>, pub move_to_attribute_bylname: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t, localName: *const cef_string_t, namespaceURI: *const cef_string_t) -> c_int>, pub move_to_first_attribute: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> c_int>, pub move_to_next_attribute: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> c_int>, pub move_to_carrying_element: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> c_int>,
}
Structure that supports the reading of XML data via the libxml streaming API. The functions of this structure should only be called on the thread that creates the object.

NOTE: This struct is allocated DLL-side.

Fields

base: cef_base_ref_counted_t

Base structure.

move_to_next_node: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> c_int>

Moves the cursor to the next node in the document. This function must be called at least once to set the current cursor position. Returns true (1) if the cursor position was set successfully.

close: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> c_int>

Close the document. This should be called directly to ensure that cleanup occurs on the correct thread.

has_error: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> c_int>

Returns true (1) if an error has been reported by the XML parser.

get_error: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> cef_string_userfree_t>

Returns the error string.

get_type: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> cef_xml_node_type_t>

Returns the node type.

get_depth: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> c_int>

Returns the node depth. Depth starts at 0 for the root node.

get_local_name: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> cef_string_userfree_t>

Returns the local name. See http://www.w3.org/TR/REC-xml-names/#NT- LocalPart for additional details.

get_prefix: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> cef_string_userfree_t>

Returns the namespace prefix. See http://www.w3.org/TR/REC-xml-names/ for additional details.

get_qualified_name: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> cef_string_userfree_t>

Returns the qualified name, equal to (Prefix:)LocalName. See http://www.w3.org/TR/REC-xml-names/#ns-qualnames for additional details.

get_namespace_uri: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> cef_string_userfree_t>

Returns the URI defining the namespace associated with the node. See http://www.w3.org/TR/REC-xml-names/ for additional details.

get_base_uri: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> cef_string_userfree_t>

Returns the base URI of the node. See http://www.w3.org/TR/xmlbase/ for additional details.

get_xml_lang: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> cef_string_userfree_t>

Returns the xml:lang scope within which the node resides. See http://www.w3.org/TR/REC-xml/#sec-lang-tag for additional details.

is_empty_element: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> c_int>

Returns true (1) if the node represents an NULL element. “” is considered NULL but “” is not.

has_value: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> c_int>

Returns true (1) if the node has a text value.

get_value: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> cef_string_userfree_t>

Returns the text value.

has_attributes: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> c_int>

Returns true (1) if the node has attributes.

get_attribute_count: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> usize>

Returns the number of attributes.

get_attribute_byindex: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t, index: c_int) -> cef_string_userfree_t>

Returns the value of the attribute at the specified 0-based index.

get_attribute_byqname: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t, qualifiedName: *const cef_string_t) -> cef_string_userfree_t>

Returns the value of the attribute with the specified qualified name.

get_attribute_bylname: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t, localName: *const cef_string_t, namespaceURI: *const cef_string_t) -> cef_string_userfree_t>

Returns the value of the attribute with the specified local name and namespace URI.

get_inner_xml: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> cef_string_userfree_t>

Returns an XML representation of the current node’s children.

get_outer_xml: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> cef_string_userfree_t>

Returns an XML representation of the current node including its children.

get_line_number: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> c_int>

Returns the line number for the current node.

move_to_attribute_byindex: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t, index: c_int) -> c_int>

Moves the cursor to the attribute at the specified 0-based index. Returns true (1) if the cursor position was set successfully.

move_to_attribute_byqname: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t, qualifiedName: *const cef_string_t) -> c_int>

Moves the cursor to the attribute with the specified qualified name. Returns true (1) if the cursor position was set successfully.

move_to_attribute_bylname: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t, localName: *const cef_string_t, namespaceURI: *const cef_string_t) -> c_int>

Moves the cursor to the attribute with the specified local name and namespace URI. Returns true (1) if the cursor position was set successfully.

move_to_first_attribute: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> c_int>

Moves the cursor to the first attribute in the current element. Returns true (1) if the cursor position was set successfully.

move_to_next_attribute: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> c_int>

Moves the cursor to the next attribute in the current element. Returns true (1) if the cursor position was set successfully.

move_to_carrying_element: Option<unsafe extern "C" fn(self_: *mut _cef_xml_reader_t) -> c_int>

Moves the cursor back to the carrying element. Returns true (1) if the cursor position was set successfully.