_cef_zip_reader_t

Struct _cef_zip_reader_t 

#[repr(C)]
pub struct _cef_zip_reader_t {
Show 13 fields pub base: cef_base_ref_counted_t, pub move_to_first_file: Option<unsafe extern "C" fn(self_: *mut _cef_zip_reader_t) -> c_int>, pub move_to_next_file: Option<unsafe extern "C" fn(self_: *mut _cef_zip_reader_t) -> c_int>, pub move_to_file: Option<unsafe extern "C" fn(self_: *mut _cef_zip_reader_t, fileName: *const cef_string_t, caseSensitive: c_int) -> c_int>, pub close: Option<unsafe extern "C" fn(self_: *mut _cef_zip_reader_t) -> c_int>, pub get_file_name: Option<unsafe extern "C" fn(self_: *mut _cef_zip_reader_t) -> cef_string_userfree_t>, pub get_file_size: Option<unsafe extern "C" fn(self_: *mut _cef_zip_reader_t) -> i64>, pub get_file_last_modified: Option<unsafe extern "C" fn(self_: *mut _cef_zip_reader_t) -> cef_basetime_t>, pub open_file: Option<unsafe extern "C" fn(self_: *mut _cef_zip_reader_t, password: *const cef_string_t) -> c_int>, pub close_file: Option<unsafe extern "C" fn(self_: *mut _cef_zip_reader_t) -> c_int>, pub read_file: Option<unsafe extern "C" fn(self_: *mut _cef_zip_reader_t, buffer: *mut c_void, bufferSize: usize) -> c_int>, pub tell: Option<unsafe extern "C" fn(self_: *mut _cef_zip_reader_t) -> i64>, pub eof: Option<unsafe extern "C" fn(self_: *mut _cef_zip_reader_t) -> c_int>,
}
Structure that supports the reading of zip archives via the zlib unzip API. The functions of this structure should only be called on the thread that creates the object.

NOTE: This struct is allocated DLL-side.

Fields

base: cef_base_ref_counted_t

Base structure.

move_to_first_file: Option<unsafe extern "C" fn(self_: *mut _cef_zip_reader_t) -> c_int>

Moves the cursor to the first file in the archive. Returns true (1) if the cursor position was set successfully.

move_to_next_file: Option<unsafe extern "C" fn(self_: *mut _cef_zip_reader_t) -> c_int>

Moves the cursor to the next file in the archive. Returns true (1) if the cursor position was set successfully.

move_to_file: Option<unsafe extern "C" fn(self_: *mut _cef_zip_reader_t, fileName: *const cef_string_t, caseSensitive: c_int) -> c_int>

Moves the cursor to the specified file in the archive. If |caseSensitive| is true (1) then the search will be case sensitive. Returns true (1) if the cursor position was set successfully.

close: Option<unsafe extern "C" fn(self_: *mut _cef_zip_reader_t) -> c_int>

Closes the archive. This should be called directly to ensure that cleanup occurs on the correct thread.

get_file_name: Option<unsafe extern "C" fn(self_: *mut _cef_zip_reader_t) -> cef_string_userfree_t>

Returns the name of the file.

get_file_size: Option<unsafe extern "C" fn(self_: *mut _cef_zip_reader_t) -> i64>

Returns the uncompressed size of the file.

get_file_last_modified: Option<unsafe extern "C" fn(self_: *mut _cef_zip_reader_t) -> cef_basetime_t>

Returns the last modified timestamp for the file.

open_file: Option<unsafe extern "C" fn(self_: *mut _cef_zip_reader_t, password: *const cef_string_t) -> c_int>

Opens the file for reading of uncompressed data. A read password may optionally be specified.

close_file: Option<unsafe extern "C" fn(self_: *mut _cef_zip_reader_t) -> c_int>

Closes the file.

read_file: Option<unsafe extern "C" fn(self_: *mut _cef_zip_reader_t, buffer: *mut c_void, bufferSize: usize) -> c_int>

Read uncompressed file contents into the specified buffer. Returns < 0 if an error occurred, 0 if at the end of file, or the number of bytes read.

tell: Option<unsafe extern "C" fn(self_: *mut _cef_zip_reader_t) -> i64>

Returns the current offset in the uncompressed file contents.

eof: Option<unsafe extern "C" fn(self_: *mut _cef_zip_reader_t) -> c_int>

Returns true (1) if at end of the file contents.