#[repr(transparent)]pub struct cef_urlrequest_flags_t(pub c_uint);Expand description
Flags used to customize the behavior of CefURLRequest.
Tuple Fields
0: c_uintImplementations
Sourceimpl cef_urlrequest_flags_t
impl cef_urlrequest_flags_t
Sourcepub const UR_FLAG_NONE: cef_urlrequest_flags_t
pub const UR_FLAG_NONE: cef_urlrequest_flags_t
Default behavior.
Sourcepub const UR_FLAG_SKIP_CACHE: cef_urlrequest_flags_t
pub const UR_FLAG_SKIP_CACHE: cef_urlrequest_flags_t
If set the cache will be skipped when handling the request. Setting this value is equivalent to specifying the “Cache-Control: no-cache” request header. Setting this value in combination with UR_FLAG_ONLY_FROM_CACHE will cause the request to fail.
Sourcepub const UR_FLAG_ONLY_FROM_CACHE: cef_urlrequest_flags_t
pub const UR_FLAG_ONLY_FROM_CACHE: cef_urlrequest_flags_t
If set the request will fail if it cannot be served from the cache (or some equivalent local store). Setting this value is equivalent to specifying the “Cache-Control: only-if-cached” request header. Setting this value in combination with UR_FLAG_SKIP_CACHE or UR_FLAG_DISABLE_CACHE will cause the request to fail.
Sourcepub const UR_FLAG_DISABLE_CACHE: cef_urlrequest_flags_t
pub const UR_FLAG_DISABLE_CACHE: cef_urlrequest_flags_t
If set the cache will not be used at all. Setting this value is equivalent to specifying the “Cache-Control: no-store” request header. Setting this value in combination with UR_FLAG_ONLY_FROM_CACHE will cause the request to fail.
Sourcepub const UR_FLAG_ALLOW_STORED_CREDENTIALS: cef_urlrequest_flags_t
pub const UR_FLAG_ALLOW_STORED_CREDENTIALS: cef_urlrequest_flags_t
If set user name, password, and cookies may be sent with the request, and cookies may be saved from the response.
Sourcepub const UR_FLAG_REPORT_UPLOAD_PROGRESS: cef_urlrequest_flags_t
pub const UR_FLAG_REPORT_UPLOAD_PROGRESS: cef_urlrequest_flags_t
If set upload progress events will be generated when a request has a body.
Sourcepub const UR_FLAG_NO_DOWNLOAD_DATA: cef_urlrequest_flags_t
pub const UR_FLAG_NO_DOWNLOAD_DATA: cef_urlrequest_flags_t
If set the CefURLRequestClient::OnDownloadData method will not be called.
Sourcepub const UR_FLAG_NO_RETRY_ON_5XX: cef_urlrequest_flags_t
pub const UR_FLAG_NO_RETRY_ON_5XX: cef_urlrequest_flags_t
If set 5XX redirect errors will be propagated to the observer instead of automatically re-tried. This currently only applies for requests originated in the browser process.
Sourcepub const UR_FLAG_STOP_ON_REDIRECT: cef_urlrequest_flags_t
pub const UR_FLAG_STOP_ON_REDIRECT: cef_urlrequest_flags_t
If set 3XX responses will cause the fetch to halt immediately rather than continue through the redirect.