cef_dll_sys

Type Alias cef_button_t

pub type cef_button_t = _cef_button_t;
A View representing a button. Depending on the specific type, the button could be implemented by a native control or custom rendered. Methods must be called on the browser process UI thread unless otherwise indicated.

Aliased Type

struct cef_button_t {
    pub base: _cef_view_t,
    pub as_label_button: Option<unsafe extern "C" fn(_: *mut _cef_button_t) -> *mut _cef_label_button_t>,
    pub set_state: Option<unsafe extern "C" fn(_: *mut _cef_button_t, _: cef_button_state_t)>,
    pub get_state: Option<unsafe extern "C" fn(_: *mut _cef_button_t) -> cef_button_state_t>,
    pub set_ink_drop_enabled: Option<unsafe extern "C" fn(_: *mut _cef_button_t, _: i32)>,
    pub set_tooltip_text: Option<unsafe extern "C" fn(_: *mut _cef_button_t, _: *const _cef_string_utf16_t)>,
    pub set_accessible_name: Option<unsafe extern "C" fn(_: *mut _cef_button_t, _: *const _cef_string_utf16_t)>,
}

Fields

base: _cef_view_t

Base structure.

as_label_button: Option<unsafe extern "C" fn(_: *mut _cef_button_t) -> *mut _cef_label_button_t>

Returns this Button as a LabelButton or NULL if this is not a LabelButton.

set_state: Option<unsafe extern "C" fn(_: *mut _cef_button_t, _: cef_button_state_t)>

Sets the current display state of the Button.

get_state: Option<unsafe extern "C" fn(_: *mut _cef_button_t) -> cef_button_state_t>

Returns the current display state of the Button.

set_ink_drop_enabled: Option<unsafe extern "C" fn(_: *mut _cef_button_t, _: i32)>

Sets the Button will use an ink drop effect for displaying state changes.

set_tooltip_text: Option<unsafe extern "C" fn(_: *mut _cef_button_t, _: *const _cef_string_utf16_t)>

Sets the tooltip text that will be displayed when the user hovers the mouse cursor over the Button.

set_accessible_name: Option<unsafe extern "C" fn(_: *mut _cef_button_t, _: *const _cef_string_utf16_t)>

Sets the accessible name that will be exposed to assistive technology (AT).