cef_component_t

Type Alias cef_component_t 

pub type cef_component_t = _cef_component_t;
Structure representing a snapshot of a component’s state at the time of retrieval. To get updated information, retrieve a new cef_component_t object via cef_component_updater_t::GetComponentByID or GetComponents. The functions of this structure may be called on any thread.

NOTE: This struct is allocated DLL-side.

Aliased Type

#[repr(C)]
pub struct cef_component_t { pub base: _cef_base_ref_counted_t, pub get_id: Option<unsafe extern "C" fn(*mut _cef_component_t) -> *mut _cef_string_utf16_t>, pub get_name: Option<unsafe extern "C" fn(*mut _cef_component_t) -> *mut _cef_string_utf16_t>, pub get_version: Option<unsafe extern "C" fn(*mut _cef_component_t) -> *mut _cef_string_utf16_t>, pub get_state: Option<unsafe extern "C" fn(*mut _cef_component_t) -> cef_component_state_t>, }

Fields

base: _cef_base_ref_counted_t

Base structure.

get_id: Option<unsafe extern "C" fn(*mut _cef_component_t) -> *mut _cef_string_utf16_t>

Returns the unique identifier for this component.

get_name: Option<unsafe extern "C" fn(*mut _cef_component_t) -> *mut _cef_string_utf16_t>

Returns the human-readable name of this component. Returns an NULL string if the component is not installed.

get_version: Option<unsafe extern "C" fn(*mut _cef_component_t) -> *mut _cef_string_utf16_t>

Returns the version of this component as a string (e.g., “1.2.3.4”). Returns an NULL string if the component is not installed.

get_state: Option<unsafe extern "C" fn(*mut _cef_component_t) -> cef_component_state_t>

Returns the state of this component at the time this object was created. A component is considered installed when its state is one of: CEF_COMPONENT_STATE_UPDATED, CEF_COMPONENT_STATE_UP_TO_DATE, or CEF_COMPONENT_STATE_RUN.