Type Alias cef_layout_t

pub type cef_layout_t = _cef_layout_t;
A Layout handles the sizing of the children of a Panel according to implementation-specific heuristics. Methods must be called on the browser process UI thread unless otherwise indicated.

NOTE: This struct is allocated DLL-side.

Aliased Type

struct cef_layout_t {
    pub base: _cef_base_ref_counted_t,
    pub as_box_layout: Option<unsafe extern "C" fn(*mut _cef_layout_t) -> *mut _cef_box_layout_t>,
    pub as_fill_layout: Option<unsafe extern "C" fn(*mut _cef_layout_t) -> *mut _cef_fill_layout_t>,
    pub is_valid: Option<unsafe extern "C" fn(*mut _cef_layout_t) -> i32>,
}

Fields

base: _cef_base_ref_counted_t

Base structure.

as_box_layout: Option<unsafe extern "C" fn(*mut _cef_layout_t) -> *mut _cef_box_layout_t>

Returns this Layout as a BoxLayout or NULL if this is not a BoxLayout.

as_fill_layout: Option<unsafe extern "C" fn(*mut _cef_layout_t) -> *mut _cef_fill_layout_t>

Returns this Layout as a FillLayout or NULL if this is not a FillLayout.

is_valid: Option<unsafe extern "C" fn(*mut _cef_layout_t) -> i32>

Returns true (1) if this Layout is valid.