cef_dll_sys

Type Alias cef_v8handler_t

pub type cef_v8handler_t = _cef_v8handler_t;
Structure that should be implemented to handle V8 function calls. The functions of this structure will be called on the thread associated with the V8 function.

Aliased Type

struct cef_v8handler_t {
    pub base: _cef_base_ref_counted_t,
    pub execute: Option<unsafe extern "C" fn(_: *mut _cef_v8handler_t, _: *const _cef_string_utf16_t, _: *mut _cef_v8value_t, _: usize, _: *const *mut _cef_v8value_t, _: *mut *mut _cef_v8value_t, _: *mut _cef_string_utf16_t) -> i32>,
}

Fields

base: _cef_base_ref_counted_t

Base structure.

execute: Option<unsafe extern "C" fn(_: *mut _cef_v8handler_t, _: *const _cef_string_utf16_t, _: *mut _cef_v8value_t, _: usize, _: *const *mut _cef_v8value_t, _: *mut *mut _cef_v8value_t, _: *mut _cef_string_utf16_t) -> i32>

Handle execution of the function identified by |name|. |object| is the receiver (‘this’ object) of the function. |arguments| is the list of arguments passed to the function. If execution succeeds set |retval| to the function return value. If execution fails set |exception| to the exception that will be thrown. Return true (1) if execution was handled.