#[repr(C)]pub struct _cef_server_t {Show 14 fields
pub base: cef_base_ref_counted_t,
pub get_task_runner: Option<unsafe extern "C" fn(self_: *mut _cef_server_t) -> *mut _cef_task_runner_t>,
pub shutdown: Option<unsafe extern "C" fn(self_: *mut _cef_server_t)>,
pub is_running: Option<unsafe extern "C" fn(self_: *mut _cef_server_t) -> c_int>,
pub get_address: Option<unsafe extern "C" fn(self_: *mut _cef_server_t) -> cef_string_userfree_t>,
pub has_connection: Option<unsafe extern "C" fn(self_: *mut _cef_server_t) -> c_int>,
pub is_valid_connection: Option<unsafe extern "C" fn(self_: *mut _cef_server_t, connection_id: c_int) -> c_int>,
pub send_http200_response: Option<unsafe extern "C" fn(self_: *mut _cef_server_t, connection_id: c_int, content_type: *const cef_string_t, data: *const c_void, data_size: usize)>,
pub send_http404_response: Option<unsafe extern "C" fn(self_: *mut _cef_server_t, connection_id: c_int)>,
pub send_http500_response: Option<unsafe extern "C" fn(self_: *mut _cef_server_t, connection_id: c_int, error_message: *const cef_string_t)>,
pub send_http_response: Option<unsafe extern "C" fn(self_: *mut _cef_server_t, connection_id: c_int, response_code: c_int, content_type: *const cef_string_t, content_length: i64, extra_headers: cef_string_multimap_t)>,
pub send_raw_data: Option<unsafe extern "C" fn(self_: *mut _cef_server_t, connection_id: c_int, data: *const c_void, data_size: usize)>,
pub close_connection: Option<unsafe extern "C" fn(self_: *mut _cef_server_t, connection_id: c_int)>,
pub send_web_socket_message: Option<unsafe extern "C" fn(self_: *mut _cef_server_t, connection_id: c_int, data: *const c_void, data_size: usize)>,
}Expand description
Structure representing a server that supports HTTP and WebSocket requests. Server capacity is limited and is intended to handle only a small number of simultaneous connections (e.g. for communicating between applications on localhost). The functions of this structure are safe to call from any thread in the brower process unless otherwise indicated.
NOTE: This struct is allocated DLL-side.
Fields
base: cef_base_ref_counted_tBase structure.
get_task_runner: Option<unsafe extern "C" fn(self_: *mut _cef_server_t) -> *mut _cef_task_runner_t>Returns the task runner for the dedicated server thread.
shutdown: Option<unsafe extern "C" fn(self_: *mut _cef_server_t)>Stop the server and shut down the dedicated server thread. See cef_server_handler_t::OnServerCreated documentation for a description of server lifespan.
is_running: Option<unsafe extern "C" fn(self_: *mut _cef_server_t) -> c_int>Returns true (1) if the server is currently running and accepting incoming connections. See cef_server_handler_t::OnServerCreated documentation for a description of server lifespan. This function must be called on the dedicated server thread.
get_address: Option<unsafe extern "C" fn(self_: *mut _cef_server_t) -> cef_string_userfree_t>Returns the server address including the port number.
has_connection: Option<unsafe extern "C" fn(self_: *mut _cef_server_t) -> c_int>Returns true (1) if the server currently has a connection. This function must be called on the dedicated server thread.
is_valid_connection: Option<unsafe extern "C" fn(self_: *mut _cef_server_t, connection_id: c_int) -> c_int>Returns true (1) if |connection_id| represents a valid connection. This function must be called on the dedicated server thread.
send_http200_response: Option<unsafe extern "C" fn(self_: *mut _cef_server_t, connection_id: c_int, content_type: *const cef_string_t, data: *const c_void, data_size: usize)>Send an HTTP 200 “OK” response to the connection identified by |connection_id|. |content_type| is the response content type (e.g. “text/html”), |data| is the response content, and |data_size| is the size of |data| in bytes. The contents of |data| will be copied. The connection will be closed automatically after the response is sent.
send_http404_response: Option<unsafe extern "C" fn(self_: *mut _cef_server_t, connection_id: c_int)>Send an HTTP 404 “Not Found” response to the connection identified by |connection_id|. The connection will be closed automatically after the response is sent.
send_http500_response: Option<unsafe extern "C" fn(self_: *mut _cef_server_t, connection_id: c_int, error_message: *const cef_string_t)>Send an HTTP 500 “Internal Server Error” response to the connection identified by |connection_id|. |error_message| is the associated error message. The connection will be closed automatically after the response is sent.
send_http_response: Option<unsafe extern "C" fn(self_: *mut _cef_server_t, connection_id: c_int, response_code: c_int, content_type: *const cef_string_t, content_length: i64, extra_headers: cef_string_multimap_t)>Send a custom HTTP response to the connection identified by |connection_id|. |response_code| is the HTTP response code sent in the status line (e.g. 200), |content_type| is the response content type sent as the “Content-Type” header (e.g. “text/html”), |content_length| is the expected content length, and |extra_headers| is the map of extra response headers. If |content_length| is >= 0 then the “Content-Length” header will be sent. If |content_length| is 0 then no content is expected and the connection will be closed automatically after the response is sent. If |content_length| is < 0 then no “Content-Length” header will be sent and the client will continue reading until the connection is closed. Use the SendRawData function to send the content, if applicable, and call CloseConnection after all content has been sent.
send_raw_data: Option<unsafe extern "C" fn(self_: *mut _cef_server_t, connection_id: c_int, data: *const c_void, data_size: usize)>Send raw data directly to the connection identified by |connection_id|. |data| is the raw data and |data_size| is the size of |data| in bytes. The contents of |data| will be copied. No validation of |data| is performed internally so the client should be careful to send the amount indicated by the “Content-Length” header, if specified. See SendHttpResponse documentation for intended usage.
close_connection: Option<unsafe extern "C" fn(self_: *mut _cef_server_t, connection_id: c_int)>Close the connection identified by |connection_id|. See SendHttpResponse documentation for intended usage.
send_web_socket_message: Option<unsafe extern "C" fn(self_: *mut _cef_server_t, connection_id: c_int, data: *const c_void, data_size: usize)>Send a WebSocket message to the connection identified by |connection_id|. |data| is the response content and |data_size| is the size of |data| in bytes. The contents of |data| will be copied. See cef_server_handler_t::OnWebSocketRequest documentation for intended usage.